pywr.parameters.DeficitParameter — Pywr 0.5dev documentation

# pywr.parameters.DeficitParameter

class `pywr.parameters.` `DeficitParameter`

  Parameter track the deficit (max_flow - actual flow) of a Node

  Parameters: | model : pywr.model.Model node : Node The node that will have it’s deficit tracked

  Notes

  This parameter is a little unusual in that it’s value is calculated during the after method, not calc_values. It is intended to be used in combination with a recorder (e.g. NumpyArrayNodeRecorder) to record the deficit ( defined as requested - actual flow) at a node. Note that this means recording this parameter does not give you the value that was used by the solver in this timestep. Alternatively, this parameter can be used in the model by other parameters and will evaluate to yesterdays deficit, where the deficit in the zeroth timestep is zero.

  `__init__`($self, /, *args, **kwargs)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `after` |
  `before` |
  `finish` |
  `get_all_values` |
  `get_double_lower_bounds` |
  `get_double_upper_bounds` |
  `get_double_variables` |
  `get_integer_lower_bounds` |
  `get_integer_upper_bounds` |
  `get_integer_variables` |
  `get_value` |
  `load` |
  `lower_bounds` |
  `register` |
  `reset` |
  `set_double_variables` |
  `set_integer_variables` |
  `setup` |
  `unregister` |
  `update` |
  `upper_bounds` |
  `value` |

  Attributes

  `children` |
  `comment` |
  `double_size` |
  `integer_size` |
  `is_variable` |
  `model` |
  `name` |
  `node` |
  `parents` |
  `size` |